==> schemacrawler-16.19.1-1.src.tar.gz: SchemaCrawler-16.19.1/.github/README.md <==
<!-- markdownlint-disable MD041 -->
![GitHub Repo stars](https://img.shields.io/github/stars/schemacrawler/schemacrawler?style=social)
[![Quick Build](https://github.com/schemacrawler/SchemaCrawler/workflows/Quick%20Build/badge.svg)](https://github.com/schemacrawler/SchemaCrawler/actions?query=workflow%3A%22Quick+Build%22)
[![Integration Tests](https://github.com/schemacrawler/SchemaCrawler/workflows/Integration%20Tests/badge.svg)](https://github.com/schemacrawler/SchemaCrawler/actions?query=workflow%3A%22Integration+Tests%22)
[![codecov](https://codecov.io/gh/schemacrawler/SchemaCrawler/branch/master/graph/badge.svg)](https://app.codecov.io/gh/schemacrawler/SchemaCrawler)

[![The Central Repository](https://img.shields.io/maven-central/v/us.fatehi/schemacrawler.svg)](https://search.maven.org/search?q=g:us.fatehi%20schemacrawler*)
[![Main distribution](https://img.shields.io/github/downloads/schemacrawler/schemacrawler/total)](https://github.com/schemacrawler/SchemaCrawler/releases/latest)
[![Docker Pulls](https://img.shields.io/docker/pulls/schemacrawler/schemacrawler.svg)](https://hub.docker.com/r/schemacrawler/schemacrawler/)
[![Chocolatey](https://img.shields.io/chocolatey/v/schemacrawler)](https://community.chocolatey.org/packages/schemacrawler)
[![Scoop](https://img.shields.io/scoop/v/schemacrawler.svg)](https://github.com/ScoopInstaller/Main/blob/master/bucket/schemacrawler.json)


<img src="https://raw.githubusercontent.com/schemacrawler/SchemaCrawler/master/schemacrawler-website/src/site/resources/images/schemacrawler_logo.png" height="100px" width="100px" align="right" />

# SchemaCrawler

> **Note**:
> * Please see the [SchemaCrawler website](https://www.schemacrawler.com/) for more details.
> * Explore the SchemaCrawler command-line with a [live online tutorial](https://killercoda.com/schemacrawler).

## About

SchemaCrawler is a free database schema discovery and comprehension tool. SchemaCrawler has a good mix of useful features for data governance. You can [search for database schema objects](https://www.schemacrawler.com/schemacrawler_grep.html) using regular expressions, and output the schema and data in a readable text format. The output serves for database documentation, and is designed to be [diff-ed](https://en.wikipedia.org/wiki/Diff) against other database schemas. SchemaCrawler also generates [schema diagrams.](https://www.schemacrawler.com/diagramming.html) You can [execute scripts](https://www.schemacrawler.com/scripting.html) in any standard scripting language against your database. You can find potential schema design issues with [lint](https://www.schemacrawler.com/lint.html).

SchemaCrawler supports almost any database that has a JDBC driver, but for convenience is [bundled with drivers](https://www.schemacrawler.com/database-support.html) for some commonly used RDBMS systems. SchemaCrawler works with any operating system that supports Java SE 8 or better.

[SchemaCrawler is also a Java API](https://dev.to/sualeh/how-to-get-database-metadata-as-java-pojos-24li) that makes working with database metadata as easy as working with plain old Java objects.


## Licensing

SchemaCrawler is available under a number of [licenses](https://www.schemacrawler.com/license.html).


## Distributions and Downloads

Explore the SchemaCrawler command-line with a [live online tutorial](https://killercoda.com/schemacrawler).

SchemaCrawler is available in a number of formats, including a download with examples, source code examples, plugin starters, a Maven reporting plugin, Docker containers, operating system specific installers, and jars on The Central Repository. For a complete list, see [downloads and distributions](https://www.schemacrawler.com/downloads.html).


## Support

Please get support on [Stack Overflow](https://stackoverflow.com/search?tab=newest&q=schemacrawler), following the [Guidelines for Support](https://www.schemacrawler.com/consulting.html).

==> schemacrawler-16.19.11-1.src.tar.gz: SchemaCrawler-16.19.11/.github/README.md <==
<!-- markdownlint-disable MD041 -->
![GitHub Repo stars](https://img.shields.io/github/stars/schemacrawler/schemacrawler?style=social)
[![Quick Build](https://github.com/schemacrawler/SchemaCrawler/workflows/Quick%20Build/badge.svg)](https://github.com/schemacrawler/SchemaCrawler/actions?query=workflow%3A%22Quick+Build%22)
[![Integration Tests](https://github.com/schemacrawler/SchemaCrawler/workflows/Integration%20Tests/badge.svg)](https://github.com/schemacrawler/SchemaCrawler/actions?query=workflow%3A%22Integration+Tests%22)
[![codecov](https://codecov.io/gh/schemacrawler/SchemaCrawler/branch/main/graph/badge.svg)](https://app.codecov.io/gh/schemacrawler/SchemaCrawler)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/84c0a068ce9349f2bcaa07b5977bd932)](https://app.codacy.com/gh/schemacrawler/SchemaCrawler/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)

[![The Central Repository](https://img.shields.io/maven-central/v/us.fatehi/schemacrawler.svg)](https://search.maven.org/search?q=g:us.fatehi%20schemacrawler*)
[![Main distribution](https://img.shields.io/github/downloads/schemacrawler/schemacrawler/total)](https://github.com/schemacrawler/SchemaCrawler/releases/latest)
[![Docker Pulls](https://img.shields.io/docker/pulls/schemacrawler/schemacrawler.svg)](https://hub.docker.com/r/schemacrawler/schemacrawler/)
[![Chocolatey](https://img.shields.io/chocolatey/v/schemacrawler)](https://community.chocolatey.org/packages/schemacrawler)
[![Scoop](https://img.shields.io/scoop/v/schemacrawler.svg)](https://github.com/ScoopInstaller/Main/blob/master/bucket/schemacrawler.json)


<img src="https://raw.githubusercontent.com/schemacrawler/SchemaCrawler/main/schemacrawler-website/src/site/resources/images/schemacrawler_logo.png" height="100px" width="100px" align="right" />

# SchemaCrawler

> **Note**:
> * Please see the [SchemaCrawler website](https://www.schemacrawler.com/) for more details.
> * Explore the SchemaCrawler command-line with a [live online tutorial](https://killercoda.com/schemacrawler).

## About

SchemaCrawler is a free database schema discovery and comprehension tool. SchemaCrawler has a good mix of useful features for data governance. You can [search for database schema objects](https://www.schemacrawler.com/schemacrawler_grep.html) using regular expressions, and output the schema and data in a readable text format. The output serves for database documentation, and is designed to be [diff-ed](https://en.wikipedia.org/wiki/Diff) against other database schemas. SchemaCrawler also generates [schema diagrams.](https://www.schemacrawler.com/diagramming.html) You can [execute scripts](https://www.schemacrawler.com/scripting.html) in any standard scripting language against your database. You can find potential schema design issues with [lint](https://www.schemacrawler.com/lint.html).

SchemaCrawler supports almost any database that has a JDBC driver, but for convenience is [bundled with drivers](https://www.schemacrawler.com/database-support.html) for some commonly used RDBMS systems. SchemaCrawler works with any operating system that supports Java SE 8 or better.

[SchemaCrawler is also a Java API](https://dev.to/sualeh/how-to-get-database-metadata-as-java-pojos-24li) that makes working with database metadata as easy as working with plain old Java objects.


## Licensing

SchemaCrawler is available under a number of [licenses](https://www.schemacrawler.com/license.html).


## Distributions and Downloads

Explore the SchemaCrawler command-line with a [live online tutorial](https://killercoda.com/schemacrawler).

SchemaCrawler is available in a number of formats, including a download with examples, source code examples, plugin starters, a Maven reporting plugin, Docker containers, operating system specific installers, and jars on The Central Repository. For a complete list, see [downloads and distributions](https://www.schemacrawler.com/downloads.html).


## Support

Please get support on [Stack Overflow](https://stackoverflow.com/search?tab=newest&q=schemacrawler), following the [Guidelines for Support](https://www.schemacrawler.com/consulting.html).
